==> storify-0.0.4.tgz: package/lib/storify.js <==
var http = require('http')
  , qs = require('querystring')
  , path = require('path')
  , User = require('./user')
  , Story = require('./story');

var Storify = function(options) {
  var options = options || {};
  
  options.host = options.host || 'api.storify.com';
  options.port = options.port || 80;
  options.version = options.version || 'v1';

  this.User = User;
  this.options = options;
};

Storify.prototype = {
  
  getStory: function(username, slug, fn) {
    var self = this
      , route = path.join('/stories', username, slug);
    
    return self.get(route, function(e, res) {
      fn(e, e ? null : new Story(self, res.content));
    });
  },
  
  getUser: function(username, fn) {
    var self = this
      , route = path.join('/users', username);
      
    return self.get(route, function(e, res) {
      fn(e, e ? null : new User(self, res.content));
    });
  },
  
  auth: function(username, password, fn) {
    var self = this;
    
    return self.post('/auth', {
        username: username
      , password: password
    }, function(e, res) {
      if (e) return fn(e);
      fn(null, res.content._token, new User(self, res.content));
    });
  },
  
  get: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'get';
    return this.request(route, params, options, fn);
  },
  
  post: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'post';
    return this.request(route, params, options, fn);
  },
  
  proxy: function() {
    var self = this;
    
    return function(req, res, next) {
      var route = req.params[0] || ''
        , params = req.method == 'POST' ? req.body : req.query;
      
      self.request(route, params, { proxy: true, method: req.method }, function(e, result, headers, code) {
        res.send(result || e, headers, code);
      });
    }
  },
  
  request: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }

    options.headers = options.headers || {};
    options.method = options.method ? options.method.toLowerCase() : 'get';
    
    params.api_key =  this.options.api_key;
    params = qs.stringify(params);
    
    route = '/' + path.join(this.options.version, route);

    if (options.method == 'get') {
      route += '?' + params;
    } else if (options.method == 'post') {
      options.headers['content-type'] = 'application/x-www-form-urlencoded';
      options.headers['content-length'] = params.length;
    }
    
    var req = http.request({
        host: this.options.host
      , port: this.options.port
      , path: route
      , method: options.method
      , headers: options.headers
    }, function(res) {
      var result = '';
      res.on('data', function(chunk) {
        result += chunk;
      });
      res.on('end', function() {
        if (options.proxy) {
          return fn(null, result, res.headers, res.statusCode);
        }
        
        result = JSON.parse(result);
        if (result.code >= 400) {
          result.error.code = result.code;
          return fn(result.error, null, res.headers, res.statusCode);
        }
        return fn(null, result, res.headers, res.statusCode);
      });
      res.on('error', function(e) {
        return fn(e, null, res.headers, res.statusCode);
      });
    });
    
    req.on('error', function(e) {
      return fn({ error: { type: 'server_error', message: 'Unable to connect to the Storify API' }, code: 500 }, null, null, 500);
    });
    
    if (options.method == 'post') {
      req.write(params);
    }
    
    req.end();
  }
};

module.exports = Storify;

==> storify-0.0.5.tgz: package/lib/storify.js <==
var http = require('http')
  , qs = require('querystring')
  , path = require('path')
  , User = require('./user')
  , Story = require('./story');

var Storify = function(options) {
  var options = options || {};
  
  options.host = options.host || 'api.storify.com';
  options.port = options.port || 80;
  options.version = options.version || 'v1';

  this.User = User;
  this.options = options;
};

Storify.prototype = {
  
  getStory: function(username, slug, params, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
    }
    
    var self = this
      , route = path.join('/stories', username, slug);
    
    return self.get(route, params, function(e, res) {
      fn(e, e ? null : new Story(self, res.content));
    });
  },
  
  getUser: function(username, params, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
    }
    
    var self = this
      , route = path.join('/users', username);
      
    return self.get(route, params, function(e, res) {
      fn(e, e ? null : new User(self, res.content));
    });
  },
  
  auth: function(username, password, fn) {
    
    var self = this;
    
    return self.post('/auth', {
        username: username
      , password: password
    }, function(e, res) {
      if (e) return fn(e);
      fn(null, res.content._token, new User(self, res.content));
    });
  },
  
  get: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'get';
    return this.request(route, params, options, fn);
  },
  
  post: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }
    
    options.method = 'post';
    return this.request(route, params, options, fn);
  },
  
  proxy: function() {
    var self = this;
    
    return function(req, res, next) {
      var route = req.params[0] || ''
        , params = req.method == 'POST' ? req.body : req.query;
      
      self.request(route, params, { proxy: true, method: req.method }, function(e, result, headers, code) {
        res.send(result || e, headers, code);
      });
    }
  },
  
  request: function(route, params, options, fn) {
    if (typeof params == 'function') {
      fn = params;
      params = {};
      options = {};
    } else if (typeof options == 'function') {
      fn = options;
      options = {};
    } else {
      options = options || {};
    }

    options.headers = options.headers || {};
    options.method = options.method ? options.method.toLowerCase() : 'get';
    
    params.api_key =  this.options.api_key;
    params = qs.stringify(params);
    
    route = '/' + path.join(this.options.version, route);

    if (options.method == 'get') {
      route += '?' + params;
    } else if (options.method == 'post') {
      options.headers['content-type'] = 'application/x-www-form-urlencoded';
      options.headers['content-length'] = params.length;
    }
    
    var req = http.request({
        host: this.options.host
      , port: this.options.port
      , path: route
      , method: options.method
      , headers: options.headers
    }, function(res) {
      var result = '';
      res.on('data', function(chunk) {
        result += chunk;
      });
      res.on('end', function() {
        if (options.proxy) {
          return fn(null, result, res.headers, res.statusCode);
        }
        
        result = JSON.parse(result);
        if (result.code >= 400) {
          result.error.code = result.code;
          return fn(result.error, null, res.headers, res.statusCode);
        }
        return fn(null, result, res.headers, res.statusCode);
      });
      res.on('error', function(e) {
        return fn(e, null, res.headers, res.statusCode);
      });
    });
    
    req.on('error', function(e) {
      return fn({ error: { type: 'server_error', message: 'Unable to connect to the Storify API' }, code: 500 }, null, null, 500);
    });
    
    if (options.method == 'post') {
      req.write(params);
    }
    
    req.end();
  }
};

module.exports = Storify;
